@@ -10,11 +10,22 @@
 from datetime import datetime
 import logging
 import os
-import psycopg2
 import re
-import sqlite3
 import time
 
+try:
+    import sqlite3
+except ImportError:
+    sqlite3 = None
+
+try:
+    import psycopg2
+except ImportError:
+    psycopg2 = None
+
+if sqlite3 is None and psycopg2 is None:
+    raise ImproperlyConfigured('Either sqlite3 or psycopg2 must be installed')
+
 
 DATABASE_NAME = os.environ.get('PEEWEE_DATABASE', 'peewee.db')
 logger = logging.getLogger('peewee.logger')
@@ -194,8 +205,9 @@ class Database(object):
         
         self.execute(query, commit=True)
     
-    def drop_table(self, model_class):
-        self.execute('DROP TABLE %s;' % model_class._meta.db_table, commit=True)
+    def drop_table(self, model_class, fail_silently=False):
+        framing = fail_silently and 'DROP TABLE IF EXISTS %s;' or 'DROP TABLE %s;'
+        self.execute(framing % model_class._meta.db_table, commit=True)
 
 
 database = Database(SqliteAdapter(), DATABASE_NAME)
@@ -1143,8 +1155,8 @@ class Model(object):
                 cls._meta.database.create_index(cls, field_obj.name)
     
     @classmethod
-    def drop_table(cls):
-        cls._meta.database.drop_table(cls)
+    def drop_table(cls, fail_silently=False):
+        cls._meta.database.drop_table(cls, fail_silently)
     
     @classmethod
     def select(cls, query=None):
